==> pwa-highlight-12.1.0.tgz: package/lib/components/ContentTypes/Highlight/highlightAll.js <==
import React from 'react';
import { string, bool, shape, array, oneOfType } from 'prop-types';

import { useStyle } from '@magento/venia-ui/lib/classify';
import defaultClasses from './highlightAll.module.css';
import Carousel from './Carousel';
import { resourceUrl } from '@swissup/pwa-highlight/lib/talons/HighlightContent';

const toHTML = str => ({ __html: str });

const HighlightAll = props => {

    const {
        enabled,
        nodeClasses,
        title : {
            html,
            img: {
                src: titleImgSrc,
                width: titleImgWidth,
                height: titleImgHeight
            }
        },
        carousel
    } = props;

    if (enabled === false) {
        return '';
    }

    const titleHtml = toHTML(html.replace(titleImgSrc, resourceUrl(
        titleImgSrc, {
            width: titleImgWidth,
            height: titleImgHeight,
            fit: 'cover'
        }
    )).replace(' src="', ` width=${titleImgWidth} height=${titleImgHeight} src="`)
    );

    const classes = useStyle(defaultClasses, props.classes);

    const listNodeClasses = nodeClasses.map(cssClass => {
        return (classes[cssClass] ? `${classes[cssClass]}` : '');
    }).join(' ');
    const rootClasses = `highlight ${classes.root} ${listNodeClasses}`;
    const titleClasses = `highlight-title ${classes.title}`;
    const contentClasses = `highlight-content ${classes.content}`;

    return (
        <div className={rootClasses}>
            <div className={titleClasses} dangerouslySetInnerHTML={titleHtml} />
            <div className={contentClasses}>
                <Carousel {...carousel} />
            </div>
        </div>
    )
};

HighlightAll.propTypes = {
    classes: shape({
        title: string,
        content: string,
        root: string
    }),
    enabled: bool.isRequired,
    nodeClasses: array.isRequired,
    title: shape({
        html: string.isRequired,
        img: shape({
            src: oneOfType([bool, string]),
        })
    })
};

export default HighlightAll;

==> pwa-highlight-13.0.0.tgz: package/lib/components/ContentTypes/Highlight/highlightAll.js <==
import React from 'react';
import { string, bool, shape, array, oneOfType } from 'prop-types';

import { useStyle } from '@magento/venia-ui/lib/classify';
import defaultClasses from './highlightAll.module.css';
import Carousel from './Carousel';
import { resourceUrl } from '@swissup/pwa-highlight/lib/talons/HighlightContent';

const unescapeHtml = (html) => {
    const tempElement = document.createElement('div');
    tempElement.innerHTML = html;
    return tempElement.textContent || tempElement.innerText || "";
};
const toHTML = str => ({ __html: unescapeHtml(str) });

const HighlightAll = props => {

    const {
        enabled,
        nodeClasses,
        title : {
            html,
            img: {
                src: titleImgSrc,
                width: titleImgWidth,
                height: titleImgHeight
            }
        },
        carousel
    } = props;

    if (enabled === false) {
        return '';
    }

    const titleHtml = toHTML(html.replace(titleImgSrc, resourceUrl(
        titleImgSrc, {
            width: titleImgWidth,
            height: titleImgHeight,
            fit: 'cover'
        }
    )).replace(' src="', ` width=${titleImgWidth} height=${titleImgHeight} src="`)
    );

    const classes = useStyle(defaultClasses, props.classes);

    const listNodeClasses = nodeClasses.map(cssClass => {
        return (classes[cssClass] ? `${classes[cssClass]}` : '');
    }).join(' ');
    const rootClasses = `highlight ${classes.root} ${listNodeClasses}`;
    const titleClasses = `highlight-title ${classes.title}`;
    const contentClasses = `highlight-content ${classes.content}`;

    return (
        <div className={rootClasses}>
            <div className={titleClasses} dangerouslySetInnerHTML={titleHtml} />
            <div className={contentClasses}>
                <Carousel {...carousel} />
            </div>
        </div>
    )
};

HighlightAll.propTypes = {
    classes: shape({
        title: string,
        content: string,
        root: string
    }),
    enabled: bool.isRequired,
    nodeClasses: array.isRequired,
    title: shape({
        html: string.isRequired,
        img: shape({
            src: oneOfType([bool, string]),
        })
    })
};

export default HighlightAll;
